@@ -3,28 +3,31 @@
 
 vcspull.cli
 ~~~~~~~~~~~
-:copyright: Copyright 2013 Tony Narlock.
-:license: BSD, see LICENSE for details
 
 """
 
-from __future__ import absolute_import, division, print_function, with_statement
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
 
 import os
 import sys
+import collections
 import fnmatch
 import glob
 import logging
+import re
+
 import argparse
 import kaptan
 import argcomplete
+
+from ._compat import string_types
 from .util import expand_config, get_repos
 from .log import DebugLogFormatter
 from .repo import Repo
 
-logger = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
-import re
 VERSIONFILE = os.path.join(
     os.path.abspath(os.path.dirname(__file__)), '__init__.py'
 )
@@ -34,26 +37,25 @@ mo = re.search(VSRE, verstrline, re.M)
 if mo:
     __version__ = mo.group(1)
 
-
 config_dir = os.path.expanduser('~/.vcspull/')
 cwd_dir = os.getcwd() + '/'
 
 
-def setup_logger(logger=None, level='INFO'):
+def setup_logger(log=None, level='INFO'):
     """Setup logging for CLI use.
 
-    :param logger: instance of logger
-    :type logger: :py:class:`Logger`
+    :param log: instance of logger
+    :type log: :py:class:`Logger`
 
     """
-    if not logger:
-        logger = logging.getLogger()
-    if not logger.handlers:
+    if not log:
+        log = logging.getLogger()
+    if not log.handlers:
         channel = logging.StreamHandler()
         channel.setFormatter(DebugLogFormatter())
 
-        logger.setLevel(level)
-        logger.addHandler(channel)
+        log.setLevel(level)
+        log.addHandler(channel)
 
 
 def get_parser():
@@ -109,9 +111,11 @@ def command_load(args):
         json_config = os.path.expanduser('~/.vcspull.json')
         has_json_config = os.path.exists(json_config)
         if not has_yaml_config and not has_json_config:
-            logger.fatal('No config file found. Create a .vcspull.{yaml,conf}'
-                        ' in your $HOME directory. http://vcspull.rtfd.org for a'
-                        ' quickstart.')
+            log.fatal(
+                'No config file found. Create a .vcspull.{yaml,conf}'
+                ' in your $HOME directory. http://vcspull.rtfd.org for a'
+                ' quickstart.'
+            )
         else:
             if sum(filter(None, [has_json_config, has_yaml_config])) > int(1):
                 sys.exit(
@@ -132,7 +136,7 @@ def command_load(args):
 
             for repo_dict in get_repos(expand_config(config.get())):
                 r = Repo(repo_dict)
-                logger.debug('%s' % r)
+                log.debug('%s' % r)
                 r.update_repo()
 
 
@@ -187,7 +191,7 @@ def is_config_file(filename, extensions=['.yml', '.yaml', '.json']):
     """
 
     extensions = [extensions] if isinstance(
-        extensions, basestring) else extensions
+        extensions, string_types) else extensions
     return any(filename.endswith(e) for e in extensions)
 
 
@@ -232,8 +236,6 @@ def find_configs(
     return configs
 
 
-import collections
-
 def update(d, u):
     """Return updated dict.
 
