@@ -3,11 +3,12 @@
 
 vcspull.exc
 ~~~~~~~~~~~
-:copyright: Copyright 2013 Tony Narlock.
-:license: BSD, see LICENSE for details
 
 """
 
+from __future__ import absolute_import, division, print_function, \
+    with_statement, unicode_literals
+
 
 class PullvException(Exception):
 
